/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule auto-download-setting-dialog-view
 */

(function() {
var AutoDownloadSettingDialogView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var ModalDialogView = dixim.common.ModalDialogView;
var $ = dixim.ctt.jQuery;

/**
 * @class AutoDownloadSettingDialogView
 * @constructor
 * @param {Object} configs
 */
AutoDownloadSettingDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(AutoDownloadSettingDialogView, ModalDialogView);
dixim.autoDownload.AutoDownloadSettingDialogView = AutoDownloadSettingDialogView;
prototype = AutoDownloadSettingDialogView.prototype;
superConstructor = AutoDownloadSettingDialogView.superConstructor;

var SETTING = 'setting';

var TEMPLATE_BODY_CONTENT = [
    '<div id="auto_download_setting_field" class="dl_tbl">',
    '<dl id="auto_download_setting_move">',
    '<dt>', '${moveTitle}', '</dt>',
    '<dd>',
    '<label class="select-pointer">',
    '<input type="radio" id="auto_download_setting_move_yes" name="auto_download_setting_move" data-role="none" />',
    '<span>', '${moveYes}', '</span>',
    '</label>',
    '<label class="select-pointer">',
    '<input type="radio" id="auto_download_setting_move_no" name="auto_download_setting_move" data-role="none" />',
    '<span>', '${moveNo}', '</span>',
    '</label>',
    '</dd>',
    '</dl>',
    '<dl id="auto_download_threshold" class="none_border_bottom no_bottom">',
    '<dt>', '${threshold}', '</dt>',
    '<dd>',
    '<input type="text" maxlength="4" size="4" data-role="none" />', '<span>', '${thresholdUnit}', '</span>',
    '</dd>',
    '</dl>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'auto-download-setting-dialog'].join('');

    configs.bodyContent = TEMPLATE_BODY_CONTENT
        .replace('${moveTitle}', _('auto_download_setting_move_title'))
        .replace('${moveYes}', _('auto_download_setting_move_yes'))
        .replace('${moveNo}', _('auto_download_setting_move_no'))
        .replace('${threshold}', _('auto_download_setting_threshold'))
        .replace('${thresholdUnit}', _('auto_download_setting_threshold_unit'));

    configs.doubleDialog = true;
    configs.buttons = [
        {text: _('dialog_return_menu'), click: dixim.proxy(this.hide, this)},
        {text: _('dialog_setting'), click: dixim.proxy(this._clickSetting, this)},
    ];
    configs.title = _('auto_download_setting_auto_save_setting');

    superConstructor.prototype._initialize.call(this, configs);
};

prototype.setValue = function(data) {
    if (typeof data.allowMove !== 'undefined') {
        if (data.allowMove) {
            $('#auto_download_setting_move_yes').trigger('click');
        } else {
            $('#auto_download_setting_move_no').trigger('click');
        }
    }
    if (typeof data.size !== 'undefined') {
        $('#auto_download_threshold [type="text"]').val(data.size / 1024 / 1024 / 1024);
    }
};

prototype._clickSetting = function() {
    var data = {};

    data.allowMove = $('#auto_download_setting_move_yes').prop('checked');
    data.size = $('#auto_download_threshold [type="text"]').val();
    this.dispatchEvent(new Event(SETTING, data));
};

}());
