/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule contents-wizard-confirm-dialog-view
 */

(function() {
var TransferWizardConfirmDialogView;
var superConstructor;
var prototype;
var ModalDialogView = dixim.common.ModalDialogView;
var Formatter = dixim.ctt.util.Formatter;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var $ = dixim.ctt.jQuery;

/**
 * @class TransferWizardConfirmDialogView
 * @constructor
 * @param {Object} configs
 */
TransferWizardConfirmDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(TransferWizardConfirmDialogView, ModalDialogView);
dixim.contents.TransferWizardConfirmDialogView = TransferWizardConfirmDialogView;
prototype = TransferWizardConfirmDialogView.prototype;
superConstructor = TransferWizardConfirmDialogView.superConstructor;

var START = 'start';
var TEMPLATE_BODY_CONTENT = [
    '<div id="confirm-description-field" class="confirm-description dlg_main_msg">',
    '<span>', '${description}', '</span>',
    '</div>',
    '<div id="confirm-list-field">',
    '<div class="dlg_scroll dl_tbl">',
    '<div id="confirm-attention-field" class="confirm-attention-field color_red txt_s">',
    '<span class="confirm-attention">', '${deleteDescription}', '</span>', '<br />',
    '<span class="confirm-attention">', '${copyCountDescription}', '</span>',
    '</div>',
    '<dl>',
    '<dt class="confirm-list-description">', '${confirmDst}', '</dt>',
    '<dd class="confirm-list">', '${serverName}', '</dd>',
    '</dl>',
    '<dl>',
    '<dt class="confirm-list-description">', '${confirmSaveDst}', '</dt>',
    '<dd class="confirm-list">', '${storageName}', '</dd>',
    '</dl>',
    '</div>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'transfer-wizard-confirm-dialog-'].join('');

    this._transferConfigs = configs.transferConfigs;

    configs.title = _('contents_operation_menu_transfer');

    configs.bodyContent = TEMPLATE_BODY_CONTENT
        .replace('${description}', _('contents_transfer_wizard_confirm_description', this._transferConfigs.dataList.length))
        .replace('${deleteDescription}', _('contents_transfer_wizard_confirm_attention_delete'))
        .replace('${copyCountDescription}', _('contents_transfer_wizard_confirm_attention_copy_count'))
        .replace('${confirmDst}', _('contents_transfer_wizard_confirm_dst'))
        .replace('${serverName}', this._transferConfigs.server.friendlyName)
        .replace('${confirmSaveDst}', _('contents_transfer_wizard_confirm_save_dst'))
        .replace('${storageName}', (typeof this._transferConfigs.storage !== 'undefined') ? this._transferConfigs.storage.friendlyName : _('contents_transfer_wizard_confirm_default_save_dst'));

    configs.doubleDialog = true;
    configs.contentHeight = configs.contentHeight || '300px';
    configs.returnButton = dixim.proxy(this.hide, this);
    configs.buttons = [
        {text: _('dialog_start'), click: dixim.proxy(this._clickStart, this)},
    ];

    superConstructor.prototype._initialize.call(this, configs);
};

prototype._render = function() {
    var date;
    var startTime = this._transferConfigs.timing.startTime;
    var dataList = this._transferConfigs.dataList;
    var dataListLen = dataList.length;

    if (typeof startTime !== 'undefined') {
        date = Formatter.stringifyDate(Formatter.dcDateToDate(startTime), 'YYYY/MM/DD hh:mm');
        $('#confirm-list-field dl:last-child').after([
            '<dl>',
            '<dt id="confirm-date" class="confirm-list-description">', _('contents_transfer_wizard_confirm_start_date'), '</dt>',
            '<dd id="confirm-date-name" class="confirm-list">', date, '</dd>',
            '</dl>',
        ].join(''));
    }
    if (this._transferConfigs.server.lcPoweroff) {
        $('#confirm-list-field div:last-child').append([
            '<div>',
            '<label class="select-pointer">',
            '<input type="checkbox" id="shutdown" />',
            '<span>', _('contents_transfer_wizard_confirm_shutdown'), '</span>',
            '</label>',
            '</div>',
        ].join(''));
    }

    for (var i = 0; i < dataListLen; i += 1) {
        if (typeof dataList[i].parentalLock !== 'undefined' && dataList[i].parentalLock) {
            $('#confirm-attention-field').append([
                '<br/>', '<span class="confirm-attention">', _('contents_transfer_wizard_confirm_attention_parental'), '</span>',
            ].join(''));
            break;
        }
    }

    $('#confirm-list-field > .dlg_scroll').css('top', [$('#confirm-list-field > .dlg_scroll').parent('*').position().top, 'px'].join(''));

    superConstructor.prototype._render.call(this);
};

prototype._clickStart = function() {
    var info = {};

    if ($('#shutdown:checked').length !== 0) {
        info.shutdown = true;
    }

    this.dispatchEvent(new Event(START, info));
};

}());
