/**
 * @module dixim
 * @submodule download
 */
dixim.namespace('dixim.contents');

/**
 * @module download 
 * @submodule download-menu-view
 */

(function() {
var DownloadMenuView;
var superConstructor;
var prototype;
var _ = dixim.ctt.ResourceBundle.get;
var MenuView = dixim.common.MenuView;
var UiUtils = dixim.common.UiUtils;
var UiFunctionManager = dixim.ctt.util.UiFunctionManager;
var $ = dixim.ctt.jQuery;

/**
 * @class DownloadMenuView
 * @constructor
 * @param {Object} configs
 */
DownloadMenuView = function(configs) {
    MenuView.call(this, configs);
};

dixim.inherit(DownloadMenuView, MenuView);
dixim.contents.DownloadMenuView = DownloadMenuView;
prototype = DownloadMenuView.prototype;
superConstructor = DownloadMenuView.superConstructor;

var DOWNLOAD = 'download';
var AUTO_DOWNLOAD = 'autoDownload';
var EONKYO = 'eonkyo';
var SELECT = 'select';
var OPERATE = 'operate';
var PREV = 'prev';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.title = _('common_menu_title_download');
    configs.menuList = [];
    if (UiFunctionManager.isImplement('downloadMedia')) {
        configs.menuList.push({
            strId: 'download_menu_download',
            eventParam: DOWNLOAD,
        });
    }
    if (UiFunctionManager.isImplement('autoDownload')) {
        configs.menuList.push({
            strId: 'download_menu_auto_download',
            eventParam: AUTO_DOWNLOAD,
        });
    }
    if (UiFunctionManager.isImplement('eonkyo')) {
        configs.menuList.push({
            strId: 'download_menu_eonkyo',
            eventParam: EONKYO,
        });
    }

    superConstructor.prototype._initialize.call(this, configs);
};

/**
 * @method show
 */
prototype.show = function() {
    var menuListLen = this._menuList.length;

    $('.rootPage').html([
        '<div class="contents">',
        '<h2 id="tit_page">', this._title, '</h2>',
        '<div class="contents_inner">',
        '<div class="check-download-field">',
        '<div class="download-check-description-field txt_m page_description">',
        '<span id="download_check_description" class="download-check-description">', '</span>',
        '</div>',
        '<ul id="menu_settings_content" class="list_btn list_next list_description">',
        '</ul>',
        '</div>',
        '</div>',
        '</div>',
    ].join(''));

    UiUtils.cleanActionSettingBar();
    UiUtils.cleanActionBar();
    $('.art_tit').text(this._title);
    $('.btn_prev').show().one('click', dixim.proxy(this._clickPrev, this));

    for (var i = 0; i < menuListLen; i += 1) {
        this._addMenuList(this._menuList[i]);
    }
};

/**
 * @method hide
 */
prototype.hide = function() {
    $('.rootPage').empty();
};

prototype._addMenuList = function(data) {
    var numberOfList = $('#menu_settings_content li').length + 1;

    $('#menu_settings_content').append([
        '<li>',
        '<h4 class="txt_m">', _(data.strId), '</h4>',
        '<p class="txt_gray">', _(data.strId + '_description'), '</p>',
        '</li>',
    ].join(''));

    $('#menu_settings_content li:last-child').on('click', data, dixim.proxy(this._clickMenu, this));

    $('#download_check_description').html(_('download_menu_description', numberOfList));
};

}());
