/**
 * @module dixim
 * @submodule vdms
 */
dixim.namespace('dixim.vdms');

/**
 * @module vdms
 * @submodule permission-operation-view
 */

(function() {
var PermissionOperationView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var UiUtils = dixim.common.UiUtils;
var $ = dixim.ctt.jQuery;

/**
 * @class PermissionOperationView
 * @constructor
 * @param {Object} configs
 */
PermissionOperationView = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(PermissionOperationView, EventTarget);
dixim.vdms.PermissionOperationView = PermissionOperationView;
prototype = PermissionOperationView.prototype;
superConstructor = PermissionOperationView.superConstructor;

var PREV = 'prev';
var SELECT = 'select';
var ALLOW = 'allow';
var DENY = 'deny';
var DELETE = 'delete';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._isAllowDevice = configs.isAllowDevice || false;
    if (this._isAllowDevice) {
        this._title = _('vdms_permission_menu_allow');
    } else {
        this._title = _('vdms_permission_menu_deny');
    }
};

/**
 * @method show
 */
prototype.show = function() {
    $('.rootPage').html([
        '<div class="contents" data-enhance="false">',
        '<h2 id="tit_page">', this._title, '</h2>',
        '<div class="contents_inner">',
        '<table class="tbl_list">',
        '<colgroup>',
        '<col span="1" class="checkbox">',
        '<col span="1" class="list_info">',
        '</colgroup>',
        '<tbody>',
        '</tbody>',
        '</table>',
        '</div>',
        '</div>',
    ].join(''));

    UiUtils.cleanActionSettingBar();
    UiUtils.cleanActionBar();
    UiUtils.setActionBar('ab_select', dixim.proxy(this._clickSelect, this));
    if (this._isAllowDevice) {
        UiUtils.setActionBar('ab_deny', dixim.proxy(this._clickDeny, this));
    } else {
        UiUtils.setActionBar('ab_allow', dixim.proxy(this._clickAllow, this));
    }
    UiUtils.setActionBar('ab_delete', dixim.proxy(this._clickDelete, this));

    $('.art_tit').text(this._title);
    $('.btn_prev').show().one('click', dixim.proxy(this._clickPrev, this));
};

/**
 * @method hide
 */
prototype.hide = function() {
    $('.rootPage').empty();
};

prototype.noDevice = function() {
    var text = '';

    UiUtils.disableActionBar('ab_select');
    if (this._isAllowDevice) {
        UiUtils.disableActionBar('ab_deny');
        text = _('vdms_permission_no_allow_device');
    } else {
        UiUtils.disableActionBar('ab_allow');
        text = _('vdms_permission_no_deny_device');
    }
    UiUtils.disableActionBar('ab_delete');
    $('.contents_inner').html([
        '<div class="error-text-field txt_none">',
        '<span>', text, '</span>',
        '</div>',
    ].join(''));
};

prototype.addDevice = function(data) {
    var host = _('vdms_permission_no_host_info');
    var ip = _('vdms_permission_no_ip_info');

    if (data.host !== '') host = data.host;
    if (data.ip !== '') ip = data.ip;

    $('.contents_inner table tbody').append([
        '<tr>',
        '<td>',
        '<label class="select-pointer">', '<input type="checkbox" />',
        '<span>', '</span>',
        '</label>',
        '</td>',
        '<td>',
        '<h4 class="txt_m">', host, '</h4>',
        '<div class="list_detail txt_s">',
        '<div>', '</div>',
        '<p class="ip_t">', ip, '</p>',
        '<p class="mac_t">', data.mac, '</p>',
        '</div>',
        '</td>',
        '</tr>',
    ].join(''));
};

prototype.switchSelect = function() {
    var numberOfNotChecked = $('.tbl_list [type="checkbox"]').not(':checked').length;

    if (numberOfNotChecked > 0) {
        $('.tbl_list [type="checkbox"]').prop('checked', true);
    } else {
        $('.tbl_list [type="checkbox"]').prop('checked', false);
    }
};

prototype._clickSelect = function() {
    this.dispatchEvent(new Event(SELECT));
};

prototype._clickDeny = function() {
    var macList = [];

    $('.tbl_list [type="checkbox"]:checked').each(function() {
        macList.push($(this).closest('tr').find('.mac_t').text());
    });
    this.dispatchEvent(new Event(DENY, {macList: macList}));
};

prototype._clickAllow = function() {
    var macList = [];

    $('.tbl_list [type="checkbox"]:checked').each(function() {
        macList.push($(this).closest('tr').find('.mac_t').text());
    });
    this.dispatchEvent(new Event(ALLOW, {macList: macList}));
};

prototype._clickDelete = function() {
    var macList = [];

    $('.tbl_list [type="checkbox"]:checked').each(function() {
        macList.push($(this).closest('tr').find('.mac_t').text());
    });
    this.dispatchEvent(new Event(DELETE, {macList: macList}));
};

prototype._clickPrev = function() {
    this.dispatchEvent(new Event(PREV));
};

prototype.error = function(text) {
    $('#permission_error').remove();
    $('.contents_inner').append([
        '<div id="permission_error" class="error-text-field txt_none">',
        '<span>', text, '</span>',
        '</div>',
    ].join(''));
};

prototype.cleanList = function() {
    $('.contents_inner table tbody').empty();
};

}());
