/**
 * @module ctt
 * @submodule ctt-ad
 */
dixim.namespace('dixim.ctt.ad');

/**
 * @module ctt-ad
 * @submodule filter-setting-dialog-edit-controller
 */

(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var FilterSettingDialogView = dixim.ctt.ad.FilterSettingDialogView;
var ConfirmationDialogController = dixim.ctt.ad.ConfirmationDialogController;
var AutoDownloadApiClient = dixim.ctt.ad.AutoDownloadApiClient;
var ErrorDialog = dixim.ctt.ErrorDialog;

var FilterSettingDialogEditController;
var prototype;

/**
 * @class FilterSettingDialogEditController
 * @constructor
 * @param {Object} configs
 * @param {AutoDownloadApiClient} [configs.model]
 */
FilterSettingDialogEditController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(FilterSettingDialogEditController, EventTarget);
dixim.ctt.ad.FilterSettingDialogEditController = FilterSettingDialogEditController;
prototype = FilterSettingDialogEditController.prototype;

/**
 * Triggered when the deletion has been done.
 *
 * @event close
 * @param {Event} event
 * @param {Object} event.args
 * @param {Object} event.args.deleted true if the deletion is completed, otherwise false.
 */
var CLOSE = 'close';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {Object} configs.targetItems
 * @param {ContentsTransferApiClient} [configs.model]
 */
prototype._initialize = function(configs) {
  configs = configs || {};

  this._model = new AutoDownloadApiClient();
  this._view = new FilterSettingDialogView(configs);
  this._data = {};
  this._finish = configs.finish || function(){return;};
  this._afterClose = configs.afterClose || function(){return;};
  this._filterId = parseInt(configs.filterId, 10);
  this._fetch_setting = {};
  this._fetch_conds_list = [];
  this._after_setting = {};
  this._after_conds_list = [];
};

/**
 * @method start
 */
prototype.start = function() {
  var v = this._view;

  v.addEventListener('cancel', this._didClickCancel, this);
  v.addEventListener('submit', this._didClickSubmit, this);
  v.addEventListener('alldelete', this._didClickAllDelete, this);

  v.show();
  this._didSetFilterSettingDialog();
};

prototype._didSetFilterConds = function(cond) {
  var data = cond.value;
  var name = cond.name_str;

  if (name === "date") {
    data = [data.substr(0,4),'/',data.substr(4,2),'/',data.substr(6,2)].join('');
  }
  $(['#table_',name,' select:last'].join('')).val(cond.op);
  $(['#table_',name,' input:last'].join('')).val(data).trigger('change');
};

prototype._didSetFilterGenreConds = function(cond) {
  var values = [];
  var cond_val = parseInt(cond.value, 10);

  for (var i = 4096; i >= 1; i /= 2) {
    if (i <= cond_val) {
      values.push(i);
      cond_val -= i;
    }
  }
  for (var j = 0; j < values.length; j += 1) {
    $(['#table_',cond.name_str,' [type="checkbox"]'].join('')).each(function() {
      if (parseInt($(this).val(), 10) === values[j]) {
        $(this).prop('checked', true).triggerHandler('click');
      }
    });
  }
};

prototype._didSetFilterDayOfTheWeekConds = function(cond) {
  var values = [];
  var cond_val = parseInt(cond.value, 10);

  for (var i = 64; i >= 1; i /= 2) {
    if (i <= cond_val) {
      values.push(i);
      cond_val -= i;
    }
  }
  for (var j = 0; j < values.length; j += 1) {
    $(['#table_',cond.name_str,' [type="checkbox"]'].join('')).each(function() {
      if (parseInt($(this).val(), 10) === values[j]) {
        $(this).prop('checked', true).triggerHandler('click');
      }
    });
  }
};

prototype._didSetFilterDurationConds = function(cond) {
  var checkbox_tag;
  var hour;
  var minute;
  var minute_error;

  if (cond.op === 11) {
    checkbox_tag = $(['#table_',cond.name_str,' #checkbox_longer'].join(''));
    minute = (parseInt(cond.value, 10) / 1000) / 60 % 60;
    hour = Math.floor((parseInt(cond.value, 10) / 1000 / 60 / 60));
    $(checkbox_tag).prop('checked', true).trigger('change');
    $(checkbox_tag).next().val([hour,':',("00" + minute).slice(-2)].join('')).triggerHandler('change');
  } else if (cond.op === 9) {
    checkbox_tag = $(['#table_',cond.name_str,' #checkbox_shorter'].join(''));
    minute = (parseInt(cond.value, 10) / 1000) / 60 % 60;
    hour = Math.floor((parseInt(cond.value, 10) / 1000 / 60 / 60));
    $(checkbox_tag).prop('checked', true).trigger('change');
    $(checkbox_tag).next().val([hour,':',("00" + minute).slice(-2)].join('')).triggerHandler('change');

  } else if (cond.op === 7) {
    checkbox_tag = $(['#table_',cond.name_str,' #checkbox_equal'].join(''));
    minute = (parseInt(cond.value, 10) / 1000) / 60 % 60;
    hour = Math.floor((parseInt(cond.value, 10) / 1000 / 60 / 60));
    $(checkbox_tag).prop('checked', true).trigger('change');
    $(checkbox_tag).next().val([hour,':',("00" + minute).slice(-2)].join('')).triggerHandler('change');

    minute_error = (parseInt(cond.value2, 10) / 1000) / 60;
    $('#input_error').val(("00" + minute_error).slice(-2)).triggerHandler('change');
  }
};

prototype._didSetFilterRecordingConds = function(cond) {
  var name = cond.name_str.split('_')[1];
  var hour = Math.floor(cond.value / 60);
  var minute = cond.value % 60;

  $(['#checkbox_',name,'_time'].join('')).prop('checked', true).triggerHandler('change');
  $(['#input_',name,'_time'].join('')).val([hour,':',("00" + minute).slice(-2)].join('')).triggerHandler('change');
  $(['#input_',name,'_time_error'].join('')).val(("00" + cond.value2).slice(-2)).triggerHandler('change');
};

prototype._didSetFilterBroadcastWaveConds = function(cond) {
  var values = [];
  var cond_val = parseInt(cond.value, 10);

  for (var i = 32; i >= 1; i /= 2) {
    if (i <= cond_val) {
      values.push(i);
      cond_val -= i;
    }
  }
  for (var j = 0; j < values.length; j += 1) {
    $(['#table_',cond.name_str,' [type="checkbox"]'].join('')).each(function() {
      if (parseInt($(this).val(), 10) === values[j]) {
        $(this).prop('checked', true).triggerHandler('change');
      }
    });
  }
};

prototype._didSetFilterCopyCountConds = function(cond) {
  if (cond.op === 11 || cond.op === 12) {
    $(['#table_',cond.name_str,' #checkbox_larger'].join('')).prop('checked', true).triggerHandler('change');
    $(['#table_',cond.name_str,' #checkbox_larger'].join('')).parent('td').next().find('select').val(cond.value);
    $(['#table_',cond.name_str,' #checkbox_larger'].join('')).parent('td').next().next().find('select').val(cond.op);
  } else if (cond.op === 9 || cond.op === 10) {
    $(['#table_',cond.name_str,' #checkbox_shorter'].join('')).prop('checked', true).triggerHandler('change');
    $(['#table_',cond.name_str,' #checkbox_shorter'].join('')).parent('td').next().find('select').val(cond.value);
    $(['#table_',cond.name_str,' #checkbox_shorter'].join('')).parent('td').next().next().find('select').val(cond.op);
  } else {
    $(['#table_',cond.name_str,' #checkbox_same'].join('')).prop('checked', true).triggerHandler('change');
    $(['#table_',cond.name_str,' #checkbox_same'].join('')).parent('td').next().find('select').val(cond.value);
  }
};

prototype._didSetFilterCondSettingDialog = function(filterId) {
  var conds_list_query = {};

  conds_list_query.filterId = filterId;
  conds_list_query.success = dixim.proxy(function(e) {
    var conds = e.args.conds;
    var conds_length = conds.length;
    var date_array;

    for (var i = 0; i < conds_length; i += 1) {
      switch(conds[i].name) {
      case 1:
        conds[i] = $.extend(conds[i],{name_str: "title"});
        this._didSetFilterConds(conds[i]);
        break;
      case 2:
        conds[i] = $.extend(conds[i],{name_str: "description"});
        this._didSetFilterConds(conds[i]);
        break;
      case 3:
        conds[i] = $.extend(conds[i],{name_str: "channel"});
        this._didSetFilterConds(conds[i]);
        break;
      case 4:
        conds[i].value = parseInt(conds[i].value, 10);
        conds[i] = $.extend(conds[i],{name_str: "genre"});
        this._didSetFilterGenreConds(conds[i]);
        break;
      case 5:
        conds[i] = $.extend(conds[i],{name_str: "duration"});
        this._didSetFilterDurationConds(conds[i]);
        break;
      case 6:
        conds[i] = $.extend(conds[i],{name_str: "copy_count"});
        this._didSetFilterCopyCountConds(conds[i]);
        break;
      case 7:
        conds[i] = $.extend(conds[i],{name_str: "date"});
        date_array = conds[i].value.split('/');
        conds[i].value = [date_array[0],date_array[1],date_array[2]].join('');
        this._didSetFilterConds(conds[i]);
        break;
      case 8:
        conds[i].value = parseInt(conds[i].value, 10);
        conds[i] = $.extend(conds[i],{name_str: "day_of_the_week"});
        this._didSetFilterDayOfTheWeekConds(conds[i]);
        break;
      case 9:
        conds[i] = $.extend(conds[i],{name_str: "recording_start_time"});
        this._didSetFilterRecordingConds(conds[i]);
        break;
      case 10:
        conds[i] = $.extend(conds[i],{name_str: "recording_end_time"});
        this._didSetFilterRecordingConds(conds[i]);
        break;
      case 11:
        conds[i].value = parseInt(conds[i].value, 10);
        conds[i] = $.extend(conds[i],{name_str: "broadcast_wave"});
        this._didSetFilterBroadcastWaveConds(conds[i]);
        break;
      default:
        break;
       }
      this._fetch_conds_list.push(conds[i]);
    }
  }, this);
  conds_list_query.error = dixim.proxy(function() {
    this._showErrorDialog("ctt_error_dialog_default");
  }, this);


  this._model.fetchCondList(conds_list_query);
};

prototype._didSetFilterSettingDialog = function() {
  var filter_list_query = {};

  filter_list_query.success = dixim.proxy(function(e) {
    var filters = e.args.filters;
    var filters_length = filters.length;
    var filter;

    for (var i = 0; i < filters_length; i += 1) {
      if (filters[i].filterId === this._filterId) {
        filter = filters[i];
        $('#input_filter_name').val(filter.filterName);
        if (filter.combCond === 'AND') {
           $('#radio_and_attribute').prop('checked', true);
        } else if (filter.combCond == 'OR') {
           $('#radio_or_attribute').prop('checked', true);
         }
        this._fetch_setting.filterName = filter.filterName;
        this._fetch_setting.combCond = filter.combCond;
        this._didSetFilterCondSettingDialog(filter.filterId);
      }
    }
  }, this);
  filter_list_query.error = dixim.proxy(function() {
    this._showErrorDialog("ctt_error_dialog_default");
  }, this);

  this._model.fetchDownloadFilterList(filter_list_query);
};

prototype._didCreateCondsList = function() {
  var list = [];
  var checkAndSetCondition = function(name) {
    $(['#table_',name,' [type="text"]'].join('')).each(function() {
      var query = {};
      var this_val = $(this).val();
      var date_array;

      if (this_val !== '') {
        switch(name) {
        case 'title':
          query.name = 1;
          break;
        case 'channel':
          query.name = 3;
          break;
        case 'description':
          query.name = 2;
          break;
        case 'date':
          query.name = 7;
          date_array = this_val.split('/');
          this_val = [date_array[0],date_array[1],date_array[2]].join('');
          break;
        default:
          break;
        }
        query.op = parseInt($(this).parent('td').next().find('select').val(), 10);
        query.value = this_val;
        list.push(query);
      }
    });
  };
  var checkAndSetGenreCondition = function(name) {
    var query = {};
    var sum = 0;

    $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
      if ($(this).is(':checked')) {
        sum += parseInt($(this).val(), 10);
      }
    });
    query.name = 4;
    query.op = 1;
    query.value = sum;
    list.push(query);
  };
  var checkAndSetDayOfTheWeekCondition = function(name) {
    var query = {};
    var sum = 0;

    $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
      if ($(this).is(':checked')) {
        sum += parseInt($(this).val(), 10);
      }
    });
    query.name = 8;
    query.op = 1;
    query.value = sum;
    list.push(query);
  };
  var checkAndSetDurationCondition = function(name) {
    $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
      var duration_id = $(this).prop('id');
      var input_val = $(this).next().val();
      var error_val;
      var minute;
      var time;
      var query = {};

      if (input_val !== '') {
        minute = parseInt(input_val.split(':')[0], 10) * 60 + parseInt(input_val.split(':')[1], 10);
        time = minute * 60 * 1000;
        query.name = 5;
        if (duration_id === 'checkbox_longer') {
          query.op = 11;
          query.value = time;
          list.push(query);
        } else if (duration_id === 'checkbox_shorter') {
          query.op = 9;
          query.value = time;
          list.push(query);
        } else if (duration_id == 'checkbox_equal') {
          error_val = parseInt($(this).parent('td').next().find('input').val(), 10) * 60 * 1000;
          if (error_val !== '') {
            query.op = 7;
            query.value = time;
            query.value2 = error_val;
            list.push(query);
           }
         }
      }
    });
  };
  var checkAndSetRecordingCondition = function(name) {
    var query = {};
    var input_text;
    var time_array;

    if ($(['#table_',name,' [type="checkbox"]'].join('')).is(':checked')) {
      input_text = $(['#input_',name.split('_')[1],'_time'].join(''));
      time_array = $(input_text).val().split(':');
      query.name = (name === 'recording_start_time') ? 9: 10;
      query.op =  7;
      query.value = parseInt(time_array[0], 10) * 60 + parseInt(time_array[1], 10);
      query.value2 = parseInt($(input_text).next().next().val(), 10);
      list.push(query);
    }
  };
  var checkAndSetBroadcastWaveCondition = function(name) {
    var query = {};
    var sum = 0;

    $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
      if ($(this).is(':checked')) {
        sum += parseInt($(this).val(), 10);
      }
    });
    query.name = 11;
    query.op = 1;
    query.value = sum;
    list.push(query);
  };
  var checkAndSetCopyCountCondition = function(name) {
    $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
      var query = {};
      var this_id = $(this).prop('id');

      if ($(this).is(':checked')) {
        query.name = 6;
        if (this_id === 'checkbox_larger' || this_id === 'checkbox_shorter') {
          query.op = parseInt($(this).parent('td').next().next().find('select').val(), 10);
          query.value = $(this).parent('td').next().find('select').val();
        } else if (this_id === 'checkbox_same') {
          query.op = 7;
          query.value = $(this).parent('td').next().find('select').val();
         }
        list.push(query);
       }
    });
  };

  $('#setting_coupling_condition #exist_state').each(function() {
    var name = $(this).parent('span').prop('id').slice(0,-11);
    switch(name) {
    case 'title':
      checkAndSetCondition(name);
      break;
    case 'channel':
      checkAndSetCondition(name);
      break;
    case 'genre':
      checkAndSetGenreCondition(name);
      break;
    case 'description':
      checkAndSetCondition(name);
      break;
    case 'date':
      checkAndSetCondition(name);
      break;
    case 'day_of_the_week':
      checkAndSetDayOfTheWeekCondition(name);
      break;
    case 'duration':
      checkAndSetDurationCondition(name);
      break;
    case 'recording_start_time':
      checkAndSetRecordingCondition(name);
      break;
    case 'recording_end_time':
      checkAndSetRecordingCondition(name);
      break;
    case 'broadcast_wave':
      checkAndSetBroadcastWaveCondition(name);
      break;
    case 'copy_count':
      checkAndSetCopyCountCondition(name);
      break;
    default:
      break;
    }
  });

  return list;
};

prototype._didSetCondsWhenSubmit = function(name) {
  var conds_list = this._after_conds_list;

  $(['#table_',name,' [type="text"]'].join('')).each(function() {
    var this_value = $(this).val();
    var date_array;
    var conds = {};

    if (this_value !== '') {
      conds.name_str = name;
      switch(name) {
      case 'title':
        conds.name = 1;
        break;
      case 'channel':
        conds.name = 3;
        break;
      case 'description':
        conds.name = 2;
        break;
      case 'date':
        conds.name = 7;
        date_array = this_value.split('/');
        this_value = [date_array[0],date_array[1],date_array[2]].join('');
        break;
      default:
        break;
      }
      conds = $.extend(conds,{
          op: $(this).parent('td').next().find('select').val(),
          value: this_value
       });
      conds_list.push(conds);
    }
  });
};

prototype._didSetGenreCondsWhenSubmit = function(name) {
  var query = {};
  var sum = 0;

  $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
    var conds = {};
    if ($(this).is(':checked')) {
      sum += parseInt($(this).val(), 10);
    }
  });
  query.name = 4;
  query.op = 1;
  query.value = sum;
  this._after_conds_list.push(query);
};

prototype._didSetDayOfTheWeekCondsWhenSubmit = function(name) {
  var query = {};
  var sum = 0;

  $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
    var conds = {};
    if ($(this).is(':checked')) {
      sum += parseInt($(this).val(), 10);
    }
  });
  query.name = 8;
  query.op = 1;
  query.value = sum;
  this._after_conds_list.push(query);
};

prototype._didSetDurationCondsWhenSubmit = function(name) {
  var conds_list = this._after_conds_list;

  $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
    var this_id = $(this).prop('id');
    var conds = {};
    var time_array;
    var time;
    var error_time;

    if ($(this).is(':checked')) {
      if (this_id === 'checkbox_longer' && $('#input_longer').val() !== '') {
        time_array = $('#input_longer').val().split(':');
        time = ((parseInt(time_array[0], 10) * 60 + parseInt(time_array[1], 10)) * 60 * 1000);
        conds = {
            name: 5,
            op: 11,
            value: time
         };
        conds_list.push(conds);
      } else if (this_id === 'checkbox_shorter' && $('#input_shorter').val() !== '') {
        time_array = $('#input_shorter').val().split(':');
        time = ((parseInt(time_array[0], 10) * 60 + parseInt(time_array[1], 10)) * 60 * 1000);
        conds = {
            name: 5,
            op: 9,
            value: time
         };
        conds_list.push(conds);
      } else if (this_id === 'checkbox_equal' && $('#input_equal').val() !== '' && $('#input_error').val() !== '') {
        time_array = $('#input_equal').val().split(':');
        time = ((parseInt(time_array[0], 10) * 60 + parseInt(time_array[1], 10)) * 60 * 1000);
        error_time = parseInt($('#input_error').val(), 10) * 60 * 1000;
        conds = {
            name: 5,
            op: 7,
            value: time,
            value2: error_time
         };
        conds_list.push(conds);
      }
    }
  });
};

prototype._didSetRecordingCondsWhenSubmit = function(name) {
  var conds = {};
  var name_str = name.split('_')[1];
  var time_array = $(['#input_',name_str,'_time'].join('')).val().split(':');

  if (name_str === 'start') {
    conds.name = 9;
  } else if (name_str === 'end') {
    conds.name = 10;
  }
  conds = $.extend(conds,{
      op: 7,
      value: parseInt(time_array[0], 10) * 60 + parseInt(time_array[1], 10),
      value2: parseInt($(['#input_',name_str,'_time_error'].join('')).val(), 10)
  });
  this._after_conds_list.push(conds);
};

prototype._didSetBroadcastWaveCondsWhenSubmit = function(name) {
  var query = {};
  var sum = 0;

  $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
    var conds = {};

    if ($(this).is(':checked')) {
      sum += parseInt($(this).val(), 10);
    }
  });
  query.name = 11;
  query.op = 1;
  query.value = sum;
  this._after_conds_list.push(query);
};

prototype._didSetCopyCountCondsWhenSubmit = function(name) {
  var conds_list = this._after_conds_list;

  $(['#table_',name,' [type="checkbox"]'].join('')).each(function() {
    var conds = {};
    var this_id = $(this).prop('id');

    if ($(this).is(':checked')) {
      conds = {
          name: 6,
          value: $(this).parent('td').next().find('select').val()
       };
      if (this_id === 'checkbox_larger' || this_id === 'checkbox_shorter') {
        conds = $.extend(conds,{
            op: parseInt($(this).parent('td').next().next().find('select').val(), 10)
         });
        conds_list.push(conds);
      } else if (this_id === 'checkbox_same') {
        conds = $.extend(conds,{op: 7});
        conds_list.push(conds);
       }
    }
  });
};

prototype._didCheckCondsWhenSubmit = function() {
  var setConds = dixim.proxy(this._didSetCondsWhenSubmit, this);
  var setGenreConds = dixim.proxy(this._didSetGenreCondsWhenSubmit, this);
  var setDayOfTheWeekConds = dixim.proxy(this._didSetDayOfTheWeekCondsWhenSubmit, this);
  var setDurationConds = dixim.proxy(this._didSetDurationCondsWhenSubmit, this);
  var setRecordingConds = dixim.proxy(this._didSetRecordingCondsWhenSubmit, this);
  var setBroadcastWaveConds = dixim.proxy(this._didSetBroadcastWaveCondsWhenSubmit, this);
  var setCopyCountConds = dixim.proxy(this._didSetCopyCountCondsWhenSubmit, this);

  this._after_setting.filterName = $('#input_filter_name').val();
  if ($('#radio_and_attribute').is(':checked')) {
    this._after_setting.combCond = "AND";
  } else if ($('#radio_or_attribute').is(':checked')) {
    this._after_setting.combCond = "OR";
  }
  $('#setting_coupling_condition #exist_state').each(function() {
    var name = "";

    name = $(this).parent('span').prop('id').slice(0, -11);
    switch(name) {
    case 'title':
      setConds(name);
      break;
    case 'channel':
      setConds(name);
      break;
    case 'genre':
      setGenreConds(name);
      break;
    case 'description':
      setConds(name);
      break;
    case 'date':
      setConds(name);
      break;
    case 'day_of_the_week':
      setDayOfTheWeekConds(name);
      break;
    case 'duration':
      setDurationConds(name);
      break;
    case 'recording_start_time':
      setRecordingConds(name);
      break;
    case 'recording_end_time':
      setRecordingConds(name);
      break;
    case 'broadcast_wave':
      setBroadcastWaveConds(name);
      break;
    case 'copy_count':
      setCopyCountConds(name);
      break;
    default:
      break;
    }
  });
};

prototype._didClickSubmit = function() {
  var query = {};
  var fetch_cond = {};
  var after_cond = {};
  var add_after_length;
  var del_fetch_length;
  var checkEqualCond = function(first_cond, second_cond) {
    if (first_cond.name == second_cond.name && first_cond.op == second_cond.op && first_cond.value == second_cond.value) {
      if (typeof first_cond.value2 !== "undefined" || typeof second_cond.value2 !== "undefined") {
        return (first_cond.value2 === second_cond.value2);
      } else {
        return true;
       }
    }
    return false;
  };
  var error_func = dixim.proxy(function() {
      this._showErrorDialog("ctt_error_dialog_default");
  }, this);

  this._didCheckCondsWhenSubmit();
  if (this._after_setting.filterName === "") {
    this._view._showErrorDialog("error_dialog_no_filter_name");
    return;
  }
  if (this._fetch_setting.filterName !== this._after_setting.filterName) {
    query.filterId = this._filterId;
    query.name = this._after_setting.filterName;
    query.error = dixim.proxy(function() {
      this._showErrorDialog("ctt_error_dialog_default");
    }, this);

    this._model.updateFilterName(query);
  }
  if (this._fetch_setting.combCond !== this._after_setting.combCond) {
    query.filterId = this._filterId;
    query.combCond = this._after_setting.combCond;
    query.error = dixim.proxy(function() {
      this._showErrorDialog("ctt_error_dialog_default");
    }, this);
    this._model.updateCombCond(query);
  }

  for (var i = 0; i < this._after_conds_list.length; i += 1) {
    after_cond = this._after_conds_list[i];
    for (var j = 0; j < this._fetch_conds_list.length; j += 1) {
      fetch_cond = this._fetch_conds_list[j];
      if (checkEqualCond(after_cond, fetch_cond)) {
        this._after_conds_list.splice(i,1);
        i -= 1;
        this._fetch_conds_list.splice(j,1);
        j -= 1;
        break;
      }
    }
  }
  add_after_length = this._after_conds_list.length;
  del_fetch_length = this._fetch_conds_list.length;
  for (var k = 0; k < add_after_length; k += 1) {
    query = {
        filterId: this._filterId,
        name: parseInt(this._after_conds_list[k].name, 10),
        op: parseInt(this._after_conds_list[k].op, 10),
        value: this._after_conds_list[k].value
    };
    if (typeof this._after_conds_list[k].value2 !== "undefined") {
      query = $.extend(query, {value2: this._after_conds_list[k].value2});
    }
    query.error = error_func;
    this._model.addCond(query);
  }
  for (var l = 0; l < del_fetch_length; l += 1) {
    query = {
      condId: this._fetch_conds_list[l].condId
    };
    query.error = error_func;
    this._model.deleteCond(query);
  }
  this._didClickCancel();
};

prototype._didClickAllDelete = function() {
  var query = {};
  var cdc;
  var v = this._view;

  query.processing = function() {
    v._didCreateCouplingConditions();
    this.finish();
  };
  query.isDelete = true;
  cdc = new ConfirmationDialogController(query);

  cdc.start();
};

prototype._didClickCancel = function() {
  var query = {
      filterId: this._filterId,
      filterName: this._after_setting.filterName
  };

  this._view.destroy();
  this._afterClose(query);
  this.dispatchEvent(new Event(CLOSE));
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.destroy();
};

/**
 * @method _showErrorDialog
 * @private
 * @param {String} error error ID.
 */
prototype._showErrorDialog = function(error) {
  var dialog;
  var query = {type: error};

  if (!!this._modal) {
    this._modal.destroy();
    this._modal = null;
  }
  if (typeof error.title !== "undefined") {
    query.title = error.title;
  }
  if (typeof error.description !== "undefined") {
    query.description = error.description;
  }

  dialog = new ErrorDialog(query);
  dialog.addEventListener('close', this._didCloseModalDialog, this);

  dialog.show();
  this._modal = dialog;
};

prototype._didCloseModalDialog = function(e) {
  var args = e.args;

  if (this._modal === args.dialog) {
    this._modal.destroy();
    this._modal = null;
  }
};

}());
