/**
 * @module ctt
 * @submodule ctt-ad
 */
dixim.namespace('dixim.ctt.ad');

/**
 * @module ctt-ad
 * @submodule history-dialog-view
 */

(function() {
var Event = dixim.event.Event;
var ModalDialogView = dixim.ctt.ModalDialogView;
var AutoDownloadApiClient = dixim.ctt.ad.AutoDownloadApiClient;
var Template = dixim.ctt.util.Template;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;
var ErrorDialog = dixim.ctt.ErrorDialog;

var HistoryDialogView;
var prototype;
var superConstructor;

/**
 * @class HistoryDialogView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
HistoryDialogView = function(configs) {
  ModalDialogView.call(this, configs);
};
dixim.inherit(HistoryDialogView, ModalDialogView);
dixim.ctt.ad.HistoryDialogView = HistoryDialogView;
prototype = HistoryDialogView.prototype;
superConstructor = HistoryDialogView.superConstructor;

var TEMPLATE_CONTENT_BOX = '<div class="ctt-history-view-wrapper" />';
var TEMPLATE_LOADING = Template.LOADING_ICON_SMALL;

var TEMPLATE_BODY_CONTENT = ['<div id="history-header"></div>',
                             '<div id="history"></div>'
                             ].join('');

/**
 * Triggered when the clear button was clicked.
 *
 * @event clear
 */
var CLEAR = 'clear';

/**
 * Triggered when the close button was clicked.
 *
 * @event close
 */
var CLOSE = 'close';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var buttons;
  var buttonsError;

  configs  = configs || {};

  buttons = [
    {
      'text': _('ctt_dialog_button_label_close'),
      id: 'save',
      click: $.proxy(this._didClickClose, this),
      align: 'right'
    },
    {
      'text': _('ad_download_history_dialog_clear'),
      click: $.proxy(this._didClickClear, this),
      align: 'left'
    }
  ];

  buttonsError = [
    {
      'text': _('ctt_dialog_button_label_close'),
      click: $.proxy(this._didClickClose, this)
    }
  ];

  configs.title = configs.title || _('ad_download_history_dialog_title');
  configs.contentBox = TEMPLATE_CONTENT_BOX;
  configs.bodyContent = TEMPLATE_BODY_CONTENT;
  configs.buttons = buttons;
  configs.width = 900;
  configs.height = 350;

  this._model = new AutoDownloadApiClient();
  this._loadingIcon = $(TEMPLATE_LOADING);
  this._errorNode = null;
  this._errorButtons = buttonsError;

  superConstructor.prototype._initialize.call(this, configs);
};

prototype._didCreateDialog = function() {
  $('#history-header').html(
     [
      '<table id="history_header_table">',
      '<tr>',
      '<th class="task_name"><div>',
      _("ad_download_history_dialog_task_name"),
      '</div></th>',
      '<th class="item"><div>',
      _("ad_download_history_dialog_item"),
      '</div></th>',
      '<th class="result"><div>',
      _("ad_download_history_dialog_result"),
      '</div></th>',
      '<th class="time"><div>',
      _("ad_download_history_dialog_time"),
      '</div></th>',
      '<th class="description"><div>',
      _("ad_download_history_dialog_description"),
      '</div></th>',
      '</tr>',
      '</table>'
    ].join('')
  );
  $('#history').html(
     [
      '<table rules="rows" id="history-list"></table>'
    ].join('')
  );
};

prototype._didAddHistoryList = function(data) {
  var date = new Date();
  var year;
  var month;
  var day;
  var hour;
  var minute;
  var description;
  var data_title = data.title;
  var dst_container_path_array = data.dstContainerPath.split('/');

  dst_container_path_array.pop();
  data.task_name = data.srcFriendlyName + "(" + data.srcContainerTitle + ")" + " → " + dst_container_path_array.pop();

  date.setTime(data.lastStateChangedTime * 1000);
  year = date.getFullYear();
  month = parseInt(date.getMonth(), 10)+1;
  day = date.getDate();
  hour = ("00" + date.getHours()).slice(-2);
  minute = ("00" + date.getMinutes()).slice(-2);
  data.time = year + "/" + month + "/" + day + "  " + hour + ":" + minute;

  if (data_title.length > 14) {
    data_title = data_title.substr(0, 13) + "...";
  }

  switch(data.result) {
  case 0:
    data.result = _("ad_download_history_dialog_result_unknown");
    break;
  case 1:
    data.result = _("ad_download_history_dialog_result_reservation");
    break;
  case 2:
    data.result = _("ad_download_history_dialog_result_execute");
    break;
  case 4:
    data.result = _("ad_download_history_dialog_result_success");
    break;
  case 8:
    data.result = _("ad_download_history_dialog_result_fail");
    break;
  default:
    break;
  }

  if (!data.errorCode) {
    description = "";
  } else {
    description = _(['ctt_ad_error_',data.errorCode].join(''));
  }
  if (description.substr(0,14) === "[ctt_ad_error_") {
    description = _('ctt_ad_error_other');
  }

  $('#history-list').append(
     [
      '<tr>',
      '<td class="task_name">',
      data.task_name,
      '</td>',
      '<td class="item">',
      data.title,
      '</td>',
      '<td class="result">',
      data.result,
      '</td>',
      '<td class="time">',
      data.time,
      '</td>',
      '<td class="description">',
      description,
      '</td>',
      '</tr>'
    ].join('')
  );
};

prototype._didSetHistoryList = function() {
  var query = {};

  query.filter = "finished";

  query.success = dixim.proxy(function(e) {
    var items = e.args.items;
    var items_length = items.length;
    var fetch_task_list_query = {};

    fetch_task_list_query.success = dixim.proxy(function(e) {
      var tasks = e.args.tasks;
      var tasks_length = tasks.length;
      var item;
      var task;
      var add_history_data;

      for (var i = 0; i < items_length; i += 1) {
         item = items[i];
         for (var j = 0; j < tasks_length; j += 1) {
           task = tasks[j];
           if (item.taskId === task.taskId) {
             add_history_data = {
                 srcFriendlyName: task.srcFriendlyName,
                 srcContainerTitle: task.srcContainerTitle,
                 dstContainerId: task.dstContainerId,
                 dstContainerPath: task.dstContainerPath,
                 title: item.title,
                 result: item.state,
                 lastStateChangedTime: item.lastStateChangedTime,
                 errorCode: item.errorCode
               };
             this._didAddHistoryList(add_history_data);
            }
          }
       }
    }, this);
    fetch_task_list_query.complete = dixim.proxy(function() {
      this._loadingIcon.detach();
    }, this);
    fetch_task_list_query.error = dixim.proxy(function() {
      this._showErrorDialog("ctt_error_dialog_default");
    }, this);
    this._model.fetchTaskList(fetch_task_list_query);
  }, this);
  query.error = dixim.proxy(function() {
    this._showErrorDialog("ctt_error_dialog_default");
  }, this);

  this._model.fetchDownloadItemLog(query);
};

prototype._didRenderDialog = function(e) {
  this._didCreateDialog();
  $('.ui-dialog-buttonset').append(this._loadingIcon);
  this._didSetHistoryList();
  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype._didTitlebarCloseButtonClick = function(e) {
  e.preventDefault();
  this._didClickClose();
};

prototype._didClickClear = function() {
  this.dispatchEvent(new Event(CLEAR));
};

prototype._didClickClose = function() {
  this.dispatchEvent(new Event(CLOSE));
};

/**
 * @method _showErrorDialog
 * @private
 * @param {String} error error ID.
 */
prototype._showErrorDialog = function(error) {
  var dialog;
  var query = {type: error};

  if (!!this._modal) {
    this._modal.destroy();
    this._modal = null;
  }
  if (typeof error.title !== "undefined") {
    query.title = error.title;
  }
  if (typeof error.description !== "undefined") {
    query.description = error.description;
  }

  dialog = new ErrorDialog(query);
  dialog.addEventListener('close', this._didCloseModalDialog, this);

  dialog.show();
  this._modal = dialog;
};

prototype._didCloseModalDialog = function(e) {
  var args = e.args;

  if (this._modal === args.dialog) {
    this._modal.destroy();
    this._modal = null;
  }
};

}());
