/**
 * @module ctt
 * @submodule content-listing-view
 */
(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var ContentListToolbarView = dixim.ctt.ContentListToolbarView;
var ContentListTableView = dixim.ctt.ContentListTableView;
var $ = dixim.ctt.jQuery;

var ContentListingView;
var prototype;

/**
 * Facade of the Toolbar and the DataTable.
 *
 * @class ContentListingView
 * @uses ContentListToolbarView
 * @uses ContentListTableView
 * @constructor
 * @param {Object} configs
 */
ContentListingView = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(ContentListingView, EventTarget);
dixim.ctt.ContentListingView = ContentListingView;
prototype = ContentListingView.prototype;

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {String} configs.containerNode
 * @param {Boolean} configs.isRemote
 */
prototype._initialize = function(configs) {
  this._containerNode = configs.containerNode;
  this._isRemote = !!configs.isRemote;
  this._isAutoDelete = !!configs.isAutoDelete;
  this._isCompression = !!configs.isCompression;
};

/**
 * @method _createView
 * @private
 */
prototype._createView = function() {
  this._view = $(this._containerNode);

  this._toolbar = new ContentListToolbarView({
    containerNode: '#content-list-toolbar',
    isRemote: this._isRemote,
    isAutoDelete: this._isAutoDelete,
    isCompression: this._isCompression
  });
  this._table = new ContentListTableView({
    containerNode: '#content-list-table',
    isRemote: this._isRemote,
    isAutoDelete: this._isAutoDelete,
    isCompression: this._isCompression
  });

  // TODO:
  this._toolbar.addEventListener('*', this._relayEvent, this);
  this._table.addEventListener('*', this._relayEvent, this);
};

// TODO:
prototype._relayEvent = function(e) {
  this.dispatchEvent(new Event(e.type, e.args, e.userData));
};

prototype.getNumberOfRows = function() {
  return this._table.getNumberOfRows();
};

prototype.addRows = function(records) {
  this._table.addRows(records);
};

prototype.removeAllRows = function() {
  this._table.removeAllRows();
};

prototype.selectAllRows = function() {
  this._table.selectAllRows();
};

prototype.unselectAllRows = function() {
  this._table.unselectAllRows();
};

prototype.getSelectedRows = function() {
  return this._table.getSelectedRows();
};

prototype.enableStaticRow = function() {
  return this._table.enableStaticRow();
};

prototype.disableStaticRow = function() {
  return this._table.disableStaticRow();
};

prototype.setSortCriteria = function(criteria) {
  this._table.setSortCriteria(criteria);
};

/**
 * @method show
 */
prototype.show = function() {
  if (!!!this._view) {
    this._createView();
  }
  this._view.show();
  this._toolbar.show();
  this._table.show();
};

/**
 * @method hide
 */
prototype.hide = function() {
  this._view.hide();
  this._toolbar.hide();
  this._table.hide();
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.hide();
//  this._toolbar.destroy();
//  this._table.destroy();
  this._view = null;
};

}());
