/**
 * @module ctt
 * @submodule autodelete-view
 */
(function() {
var Event = dixim.event.Event;
var ModalDialogView = dixim.ctt.ModalDialogView;
var TickerView = dixim.ctt.TickerView;
var Template = dixim.ctt.util.Template;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var AutoDeleteView;
var prototype;
var superConstructor;

/**
 * @class AutoDeleteView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
AutoDeleteView = function(configs) {
  ModalDialogView.call(this, configs);
  this._initialize(configs);
};
dixim.inherit(AutoDeleteView, ModalDialogView);
dixim.ctt.AutoDeleteView = AutoDeleteView;
prototype = AutoDeleteView.prototype;
superConstructor = AutoDeleteView.superConstructor;

var TEMPLATE_CONTENT_BOX = '<div class="ctt-autodelete-view-wrapper" />';

var TEMPLATE_BODY_CONTENT = ['<div class="ctt-autodelete-view">',
                               '<div class="ctt-autodelete-view-first-header"></div>',
                               '<div class="ctt-autodelete-view-block">',
                                 '<div class="ctt-autodelete-view-first-label"></div>',
                                 '<br/>',
                                 '<div>',
                                   '<input type="radio" name="autodelete_radio_yes_no" class="ctt-autodelete-view-radio-yes" value="" onfocus="this.blur()"><span class="ctt-autodelete-view-yes-btn-label"></span>',
                                   '<input type="radio" name="autodelete_radio_yes_no" class="ctt-autodelete-view-radio-no" value="" onfocus="this.blur()"><span class="ctt-autodelete-view-no-btn-label"></span>',
                                 '</div>',
                                 '<br/>',
                                 '<div class="ctt-autodelete-view-first-msg"></div>',
                               '</div>',
                               '<div class="ctt-autodelete-view-second-header"></div>',
                               '<div class="ctt-autodelete-view-block">',
                                 '<div>',
                                   '<span class="ctt-autodelete-view-second-label"></span>',
                                   '<input type="text" class="ctt-autodelete-limit" style="ime-inactive;" maxlength="4" size="4"/>',
                                 '</div>',
                                 '<br/>',
                                 '<div class="ctt-autodelete-view-second-msg"></div>',
                               '</div>',
                             '</div>',
                             '<div class="ctt-autodelete-view-error"></div>'
                             ].join('');

var TEMPLATE_LOADING = Template.LOADING_ICON_SMALL;

/**
 * Triggered when the cancel button was clicked.
 *
 * @event cancel
 */
var CANCEL = 'cancel';

/**
 * Triggered when the unlock button was clicked.
 *
 * @event lock
 */
var AUTODEL = 'autodelete';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var buttons;
  var buttonsError;
  var bodyContent;

  configs  = configs || {};

  buttons = [
    {
      'text': _('ctt_autodelete_view_button_label_setting'),
      click: $.proxy(this._didClickSetting, this),
      'class': 'ctt-autodelete-view-button-setting'
    },
    {
      'text': _('ctt_dialog_button_label_cancel'),
      click: $.proxy(this._didClickCancel, this),
      align: 'left'
    }
  ];

  buttonsError = [
    {
      'text': _('ctt_dialog_button_label_close'),
      click: $.proxy(this._didClickClose, this)
    }
  ];

  bodyContent = TEMPLATE_BODY_CONTENT;

  configs.title = _('ctt_autodelete_view_title');
  configs.contentBox = configs.contentBox || TEMPLATE_CONTENT_BOX;
  configs.bodyContent = configs.bodyContent || bodyContent;
  configs.buttons = buttons;
  configs.width = 600;
  configs.height = 'auto';
  configs.maxHeight = 500;

  this._errorNode = null;
  this._errorButtons = buttonsError;
  this._intervalId = null;
  this._ticker = null;

  superConstructor.prototype._initialize.call(this, configs);
};

prototype._didRenderDialog = function(e) {
  var v = this._view;

  $('.ctt-autodelete-view-first-header', v).text(_('ctt_autodelete_view_first_header'));
  $('.ctt-autodelete-view-first-label', v).text(_('ctt_autodelete_view_first_label'));
  $('.ctt-autodelete-view-first-msg', v).text(_('ctt_autodelete_view_first_msg'));
  $('.ctt-autodelete-view-second-header', v).text(_('ctt_autodelete_view_second_header'));
  $('.ctt-autodelete-view-second-label', v).text(_('ctt_autodelete_view_second_label'));
  $('.ctt-autodelete-view-second-msg', v).text(_('ctt_autodelete_view_second_msg'));
  $('.ctt-autodelete-view-yes-btn-label').text(_('ctt_autodelete_view_first_radio_yes'));
  $('.ctt-autodelete-view-no-btn-label').text(_('ctt_autodelete_view_first_radio_no'));

  this._ticker = new TickerView({
    containerNode: $('.ctt-autodelete-view-error', v),
    type: 'error'
  });

  superConstructor.prototype._didRenderDialog.call(this, e);

  var that = this;
  this._intervalId = setInterval(function() {
    that._textFook();
  }, 500);
};

prototype.getAutoDeleteStatus = function() {
  return $(".ctt-autodelete-view-radio-yes").attr("checked");
};

prototype.getAutoDeleteLimit = function() {
  return $(".ctt-autodelete-limit").attr("value") * 1024 * 1024 * 1024;
};

prototype.setAutoDeleteStatus = function(status) {
  if (status) {
    $(".ctt-autodelete-view-radio-yes").attr("checked", true);
    $(".ctt-autodelete-view-radio-no").attr("checked", false);
  } else {
    $(".ctt-autodelete-view-radio-yes").attr("checked", false);
    $(".ctt-autodelete-view-radio-no").attr("checked", true);
  }
};

prototype.setAutoDeleteLimit = function(limit) {
  var num = limit / 1024 / 1024 / 1024 * 100;
  var gb = Math.round(num) / 100;
  $(".ctt-autodelete-limit").attr("value", gb);
};

prototype._didTitlebarCloseButtonClick = function(e) {
  e.preventDefault();
  this._didCancel();
};

prototype._didClickCancel = function(e) {
  this._didCancel();
};

prototype._didCancel = function() {
  this.dispatchEvent(new Event(CANCEL));
  if (this._intervalId) clearInterval(this._intervalId);
};

prototype._didClickClose = function() {
  this._didCancel();
};

prototype._didClickSetting = function(e) {
  this.dispatchEvent(new Event(AUTODEL));
  if (this._intervalId) clearInterval(this._intervalId);
};

prototype.startIndicator = function() {
  $('.ui-dialog-buttonset').append(TEMPLATE_LOADING);
  $('button').prop('disabled', true);
};

/**
 * @method showError
 * @param {String} error
 */
prototype.showError = function(error) {
  this._showError(error);
};

prototype._showError = function(error) {
  this._ticker.setText(error);
  this._ticker.show();
  $(".ctt-autodelete-view").hide();
  this.setButtons(this._errorButtons);
};

prototype._textFook = function(e) {
  var value = $(".ctt-autodelete-limit").attr("value");
  if (this._isNumeric(value)) {
    this.enableButton('.ctt-autodelete-view-button-setting');
  } else {
    this.disableButton('.ctt-autodelete-view-button-setting');
  }
};

prototype._isNumeric = function(num) {
    if (!!!num || num.match(/[^0-9]/g) || num < 1) {
        return false;
    }
    return true;
};

}());

function onDragStart() {
  var elem = document.activeElement;
  if (elem.className === "ctt-autodelete-limit") {
    event.returnValue = true;
  } else {
    event.returnValue = false;
  }
}

function onSelectStart() {
  var elem = document.activeElement;
  if (elem.className === "ctt-autodelete-limit") {
    event.returnValue = true;
  } else {
    event.returnValue = false;
  }
}

