/**
 * @module ctt
 * @submodule content-list-toolbar-view
 */
(function() {
var Event = dixim.event.Event;
var ToolbarView = dixim.ctt.ToolbarView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var ContentListToolbarView;
var prototype;
var superConstructor;

/**
 * @class ContentListToolbarView
 * @extends ToolbarView
 * @constructor
 * @param {Object} configs
 * @param {String} configs.containerNode
 * @param {Boolean} configs.isRemote
 */
ContentListToolbarView = function(configs) {
  ToolbarView.call(this, configs);
};
dixim.inherit(ContentListToolbarView, ToolbarView);
dixim.ctt.ContentListToolbarView = ContentListToolbarView;
prototype = ContentListToolbarView.prototype;
superConstructor = ContentListToolbarView.superConstructor;

/**
 * Select All button ID.
 *
 * @property BUTTON_ID_SELECT_ALL
 * @type {String}
 * @static
 */
ContentListToolbarView.BUTTON_ID_SELECT_ALL = 'selectAll';

/**
 * Unselect All button ID.
 *
 * @property BUTTON_ID_UNSELECT_ALL
 * @type {String}
 * @static
 */
ContentListToolbarView.BUTTON_ID_UNSELECT_ALL = 'unselectAll';

/**
 * Delete button ID.
 *
 * @property BUTTON_ID_DELETE
 * @type {String}
 * @static
 */
ContentListToolbarView.BUTTON_ID_DELETE = 'delete';

/**
 * Rename button ID.
 *
 * @property BUTTON_ID_RENAME
 * @type {String}
 * @static
 */
ContentListToolbarView.BUTTON_ID_RENAME = 'rename';

/**
 * Lock button ID.
 *
 * @property BUTTON_ID_LOCK
 * @type {String}
 * @static
 */
ContentListToolbarView.BUTTON_ID_LOCK = 'lock';

/**
 * Unlock button ID.
 *
 * @property BUTTON_ID_UNLOCK
 * @type {String}
 * @static
 */
ContentListToolbarView.BUTTON_ID_UNLOCK = 'unlock';

/**
 * Transfer button ID.
 *
 * @property BUTTON_ID_TRANSFER
 * @type {String}
 * @static
 */
ContentListToolbarView.BUTTON_ID_TRANSFER = 'transfer';

/**
 * Download button ID.
 *
 * @property BUTTON_ID_DOWNLOAD
 * @type {String}
 * @static
 */
ContentListToolbarView.BUTTON_ID_DOWNLOAD = 'download';

/**
 * Compression button ID.
 *
 * @property BUTTON_ID_COMPRESSION
 * @type {String}
 * @static
 */
ContentListToolbarView.BUTTON_ID_COMPRESSION = 'compression';

///**
// * Other button ID.
// *
// * TODO: tentative name.
// *
// * @property BUTTON_ID_OTHER
// * @type {String}
// * @static
// */
//ContentListToolbarView.BUTTON_ID_OTHER = 'other';

var BUTTONS = [
  {
    /**
     * Triggered when the Transfer button is clicked.
     *
     * @event transfer
     */
    id: ContentListToolbarView.BUTTON_ID_TRANSFER,
    label: _('ctt_toolbar_button_transfer'),
    icon: 'ico_Transfer.png',
    align: 'right'
  },
  {
    /**
     * Triggered when the Select All button is clicked.
     *
     * @event selectAll
     */
    id: ContentListToolbarView.BUTTON_ID_SELECT_ALL,
    label: _('ctt_toolbar_button_select_all'),
    icon: 'ico_SelectAll.png'
  },
  {
    /**
     * Triggered when the Unselect All button is clicked.
     *
     * @event unselectAll
     */
    id: ContentListToolbarView.BUTTON_ID_UNSELECT_ALL,
    label: _('ctt_toolbar_button_unselect_all'),
    icon: 'ico_RemoveAll.png'
  },
  {
    /**
     * Triggered when the Delete button is clicked.
     *
     * @event delete
     */
    id: ContentListToolbarView.BUTTON_ID_DELETE,
    label: _('ctt_toolbar_button_delete'),
    icon: 'ico_Delete.png'
  },
  {
    /**
     * Triggered when the Rename button is clicked.
     *
     * @event rename
     */
    id: ContentListToolbarView.BUTTON_ID_RENAME,
    label: _('ctt_toolbar_button_rename'),
    icon: 'ico_Rename.png'
  },
  {
    /**
     * Triggered when the Lock button is clicked.
     *
     * @event lock
     */
    id: ContentListToolbarView.BUTTON_ID_LOCK,
    label: _('ctt_toolbar_button_lock'),
    icon: 'ico_Lock.png'
  },
  {
    /**
     * Triggered when the Unlock button is clicked.
     *
     * @event unlock
     */
    id: ContentListToolbarView.BUTTON_ID_UNLOCK,
    label: _('ctt_toolbar_button_unlock'),
    icon: 'ico_Unlock.png'
  },
  {
  /**
     * Triggered when the Compression button is clicked.
     *
     * @event Compression
     */
    id: ContentListToolbarView.BUTTON_ID_COMPRESSION,
    label: _('ctt_toolbar_button_compression'),
    icon: 'ico_tc.png'
  },
//  {
//    id: ContentListToolbarView.BUTTON_ID_OTHER,
//    label: _('ctt_toolbar_button_other'),
//    icon: 'arrow_down.png',
//    children: [
//      {
//        id: 'children-1',
//        label: 'children 1'
//      },
//      {
//        id: 'children-2',
//        label: 'children 2'
//      },
//      {
//        id: 'children-3',
//        label: 'children 3'
//      }
//    ]
//  },
  {
    /**
     * Triggered when the Download button is clicked.
     *
     * @event download
     */
    id: ContentListToolbarView.BUTTON_ID_DOWNLOAD,
    label: _('ctt_toolbar_button_download'),
    icon: 'ico_Download.png',
    align: 'right'
  }
];

var makeButtonListByIds = function(buttonIds) {
  var buttons = [];
  var i;
  var len;
  var findIndex = dixim.array.findIndex;

  len = BUTTONS.length;
  for (i = 0; i < len; i += 1) {
    if (findIndex(buttonIds, BUTTONS[i].id) === buttonIds.length) continue;
    buttons.push(BUTTONS[i]);
  }
  return buttons;
};

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {String} configs.containerNode
 * @param {Boolean} configs.isRemote
 */
prototype._initialize = function(configs) {
  var buttons_id = [];

  if (!!configs.isRemote) {
    configs.buttons = makeButtonListByIds([
      ContentListToolbarView.BUTTON_ID_SELECT_ALL,
      ContentListToolbarView.BUTTON_ID_UNSELECT_ALL,
      ContentListToolbarView.BUTTON_ID_DOWNLOAD
    ]);
  } else {
    buttons_id.push(ContentListToolbarView.BUTTON_ID_TRANSFER);
    buttons_id.push(ContentListToolbarView.BUTTON_ID_SELECT_ALL);
    buttons_id.push(ContentListToolbarView.BUTTON_ID_UNSELECT_ALL);
    buttons_id.push(ContentListToolbarView.BUTTON_ID_DELETE);
    buttons_id.push(ContentListToolbarView.BUTTON_ID_RENAME);
    if (!!configs.isAutoDelete) {
      buttons_id.push(ContentListToolbarView.BUTTON_ID_LOCK);
      buttons_id.push(ContentListToolbarView.BUTTON_ID_UNLOCK);
    }
    if (!!configs.isCompression) {
      buttons_id.push(ContentListToolbarView.BUTTON_ID_COMPRESSION);
    }
    if (!!configs.isAutoDelete || !!configs.isCompression) {
      $('#search, #content-list-toolbar').css('height', '80px');
    }
    configs.buttons = makeButtonListByIds(buttons_id);
  }
  configs.className = 'ctt-content-list-toolbar-view';
  superConstructor.prototype._initialize.call(this, configs);
};

/**
 * @method updateActiveButtons
 * @param {String[]} buttonIds
 */
prototype.updateActiveButtons = function(buttonIds) {
  var i = 0;
  var len;
  var nodes = this._buttonNodes;
  var node;

  for (i in nodes) {
    if (!nodes.hasOwnProperty(i)) continue;
    nodes[i].hide();
  }

  len = buttonIds.length;
  for (i = 0; i < len; i += 1) {
    if (!!!(node = nodes[buttonIds[i]])) continue;
    node.show();
  }
};

/**
 * @method activateAllButtons
 */
prototype.activateAllButtons = function() {
  var i = 0;
  var nodes = this._buttonNodes;

  for (i in nodes) {
    if (!nodes.hasOwnProperty(i)) continue;
    nodes[i].show();
  }
};

/**
 * @method deactivateAllButtons
 */
prototype.deactivateAllButtons = function() {
  var i = 0;
  var nodes = this._buttonNodes;

  for (i in nodes) {
    if (!nodes.hasOwnProperty(i)) continue;
    nodes[i].hide();
  }
};

}());
