/**
 * @module ctt
 * @submodule download-destination-wizard-page-controller
 */
(function() {
var Event = dixim.event.Event;
var WizardPageController = dixim.ctt.WizardPageController;
var ContainerListingController = dixim.ctt.ContainerListingController;
var ScheduledRecordingWizardPageController = dixim.ctt.ScheduledRecordingWizardPageController;
var DownloadDestinationWizardPageView = dixim.ctt.DownloadDestinationWizardPageView;

var DownloadDestinationWizardPageController;
var prototype;
var superConstructor;

/**
 * @class DownloadDestinationWizardPageController
 * @extends WizardPageController
 * @uses DownloadDestinationWizardPageView
 * @uses ContentsTransferApiClient
 * @uses Event
 * @constructor
 * @param {Object} configs
 */
DownloadDestinationWizardPageController = function(configs) {
  WizardPageController.call(this, configs);
};
dixim.inherit(DownloadDestinationWizardPageController, WizardPageController);
dixim.ctt.DownloadDestinationWizardPageController = DownloadDestinationWizardPageController;
prototype = DownloadDestinationWizardPageController.prototype;
superConstructor = DownloadDestinationWizardPageController.superConstructor;

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  superConstructor.prototype._initialize.call(this, configs);

  this._view = new DownloadDestinationWizardPageView();
  this._containerListingController = null;
  this._model = null;
  this._session = null;
  this._enableWol = true;
};

prototype.start = function() {
  var v = this._view;
  var c;

  v.addEventListener('render', this._didRenderView, this);
  v.addEventListener('cancel', this._didCancel, this);
  v.addEventListener('next', this._didClickNext, this);

  if (!!(c = this._containerListingController)) {
    c.start();
  }
  superConstructor.prototype.start.call(this);
};

prototype._didRenderView = function(e) {
  var c;
  var model;
  var w;
  var v = this._view;

  if (!!!(w = this._wizard)) {
    throw new Error('not pushed into wizard stack.');
  }

  model = w.getRegistryEntry('model');
  targetItems = w.getRegistryEntry('targetItems');

  c = new ContainerListingController({
    containerNode: v.getBodyContent(),
    model: model,
    embedded: true
  });
  c.addEventListener('selectContainer', this._didSelectContainer, this);
  c.start();

  v.disableNextButton();
  this._containerListingController = c;
  this._model = model;
};

prototype._didSelectContainer = function(e) {
  this._view.enableNextButton();
};

prototype._didClickNext = function(e) {
  var w = this._wizard;
  var container;

  container = this._containerListingController.getSelectedContainer();
  w.setRegistryEntry('destLocalStorage', container.device);
  w.setRegistryEntry('destLocalContainer', container.container);
  w.pushViewController(new ScheduledRecordingWizardPageController());
};

prototype.stop = function() {
  superConstructor.prototype.stop.call(this);
};

prototype.destroy = function() {
  if (!!this._containerListingController) {
    this._containerListingController.removeEventListener('selectContainer', this._didSelectContainer, this);
    this._containerListingController.cancelAllSessions();
  }
  superConstructor.prototype.destroy.call(this);
};

}());